xspharm package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   xspharm.tests

Submodules
----------

xspharm.xspharm module
----------------------

.. automodule:: xspharm.xspharm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: xspharm
   :members:
   :undoc-members:
   :show-inheritance:
